@@ -17,9 +17,23 @@ def properSize(fn):
 		return 0 < size and size < (1 << 25)
 	return 0 < size and size < (1 << 23)
 
+def cutCaptionHtml(text, limit):
+	for _ in range(5):
+		text.replace('\n\n\n', '\n\n')
+	if len(text) <= limit:
+		return text
+	lines = text.split('\n')
+	count = 0
+	for ind, line in enumerate(lines):
+		count += 1 + len(line)
+		if count > limit:
+			break
+	return '\n'.join(lines[:ind]).strip()
+
 def getCap(result, limit):
 	if result.cap_html_v2:
-		return (result.cap_html_v2 + ' <a href="%s">source</a>' % result.url).strip()
+		return (cutCaptionHtml(result.cap_html_v2, limit) + 
+			' <a href="%s">source</a>' % result.url).strip()
 	if result.getParseMode() == 'HTML':
 		# currently, the only use case is repost the telegram post
 		# later on, this part might need expansion
